==> knative-model-6.8.1-sources.jar: io/fabric8/knative/internal/networking/v1alpha1/ClusterDomainClaimListFluent.java <==
package io.fabric8.knative.internal.networking.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterDomainClaimListFluent<A extends ClusterDomainClaimListFluent<A>> extends BaseFluent<A>{
  public ClusterDomainClaimListFluent() {
  }
  public ClusterDomainClaimListFluent(ClusterDomainClaimList instance) {
    instance = (instance != null ? instance : new ClusterDomainClaimList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
  }
  private String apiVersion;
  private ArrayList<ClusterDomainClaimBuilder> items = new ArrayList<ClusterDomainClaimBuilder>();
  private String kind;
  private ListMeta metadata;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(int index,ClusterDomainClaim item) {
    if (this.items == null) {this.items = new ArrayList<ClusterDomainClaimBuilder>();}
    ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  public A setToItems(int index,ClusterDomainClaim item) {
    if (this.items == null) {this.items = new ArrayList<ClusterDomainClaimBuilder>();}
    ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  public A addToItems(io.fabric8.knative.internal.networking.v1alpha1.ClusterDomainClaim... items) {
    if (this.items == null) {this.items = new ArrayList<ClusterDomainClaimBuilder>();}
    for (ClusterDomainClaim item : items) {ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<ClusterDomainClaim> items) {
    if (this.items == null) {this.items = new ArrayList<ClusterDomainClaimBuilder>();}
    for (ClusterDomainClaim item : items) {ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.knative.internal.networking.v1alpha1.ClusterDomainClaim... items) {
    if (this.items == null) return (A)this;
    for (ClusterDomainClaim item : items) {ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  public A removeAllFromItems(Collection<ClusterDomainClaim> items) {
    if (this.items == null) return (A)this;
    for (ClusterDomainClaim item : items) {ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<ClusterDomainClaimBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<ClusterDomainClaimBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      ClusterDomainClaimBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public List<ClusterDomainClaim> buildItems() {
    return items != null ? build(items) : null;
  }
  public ClusterDomainClaim buildItem(int index) {
    return this.items.get(index).build();
  }
  public ClusterDomainClaim buildFirstItem() {
    return this.items.get(0).build();
  }
  public ClusterDomainClaim buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public ClusterDomainClaim buildMatchingItem(Predicate<ClusterDomainClaimBuilder> predicate) {
    for (ClusterDomainClaimBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public boolean hasMatchingItem(Predicate<ClusterDomainClaimBuilder> predicate) {
    for (ClusterDomainClaimBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<ClusterDomainClaim> items) {
    if (this.items != null) { _visitables.get("items").clear();}
    if (items != null) {this.items = new ArrayList(); for (ClusterDomainClaim item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.knative.internal.networking.v1alpha1.ClusterDomainClaim... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (ClusterDomainClaim item :items){ this.addToItems(item);}} return (A) this;
  }
  public boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public ItemsNested<A> addNewItem() {
    return new ItemsNested(-1, null);
  }
  public ItemsNested<A> addNewItemLike(ClusterDomainClaim item) {
    return new ItemsNested(-1, item);
  }
  public ItemsNested<A> setNewItemLike(int index,ClusterDomainClaim item) {
    return new ItemsNested(index, item);
  }
  public ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public ItemsNested<A> editMatchingItem(Predicate<ClusterDomainClaimBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterDomainClaimListFluent that = (ClusterDomainClaimListFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(items, that.items)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  public class ItemsNested<N> extends ClusterDomainClaimFluent<ItemsNested<N>> implements Nested<N>{
    ItemsNested(int index,ClusterDomainClaim item) {
      this.index = index;
      this.builder = new ClusterDomainClaimBuilder(this, item);
    }
    ClusterDomainClaimBuilder builder;
    int index;
    public N and() {
      return (N) ClusterDomainClaimListFluent.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/networking/v1alpha1/ClusterDomainClaimListFluent.java <==
package io.fabric8.knative.internal.networking.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterDomainClaimListFluent<A extends ClusterDomainClaimListFluent<A>> extends BaseFluent<A>{
  public ClusterDomainClaimListFluent() {
  }
  
  public ClusterDomainClaimListFluent(ClusterDomainClaimList instance) {
    this.copyInstance(instance);
  }
  private String apiVersion;
  private ArrayList<ClusterDomainClaimBuilder> items = new ArrayList<ClusterDomainClaimBuilder>();
  private String kind;
  private ListMeta metadata;
  
  protected void copyInstance(ClusterDomainClaimList instance) {
    instance = (instance != null ? instance : new ClusterDomainClaimList());
  
    if (instance != null) {
        this.withApiVersion(instance.getApiVersion());
        this.withItems(instance.getItems());
        this.withKind(instance.getKind());
        this.withMetadata(instance.getMetadata());
        this.withApiVersion(instance.getApiVersion());
        this.withItems(instance.getItems());
        this.withKind(instance.getKind());
        this.withMetadata(instance.getMetadata());
      }
  }
  
  public String getApiVersion() {
    return this.apiVersion;
  }
  
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  public A addToItems(int index,ClusterDomainClaim item) {
    if (this.items == null) {this.items = new ArrayList<ClusterDomainClaimBuilder>();}
    ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  
  public A setToItems(int index,ClusterDomainClaim item) {
    if (this.items == null) {this.items = new ArrayList<ClusterDomainClaimBuilder>();}
    ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  
  public A addToItems(io.fabric8.knative.internal.networking.v1alpha1.ClusterDomainClaim... items) {
    if (this.items == null) {this.items = new ArrayList<ClusterDomainClaimBuilder>();}
    for (ClusterDomainClaim item : items) {ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  
  public A addAllToItems(Collection<ClusterDomainClaim> items) {
    if (this.items == null) {this.items = new ArrayList<ClusterDomainClaimBuilder>();}
    for (ClusterDomainClaim item : items) {ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  
  public A removeFromItems(io.fabric8.knative.internal.networking.v1alpha1.ClusterDomainClaim... items) {
    if (this.items == null) return (A)this;
    for (ClusterDomainClaim item : items) {ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  
  public A removeAllFromItems(Collection<ClusterDomainClaim> items) {
    if (this.items == null) return (A)this;
    for (ClusterDomainClaim item : items) {ClusterDomainClaimBuilder builder = new ClusterDomainClaimBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromItems(Predicate<ClusterDomainClaimBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<ClusterDomainClaimBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      ClusterDomainClaimBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ClusterDomainClaim> buildItems() {
    return items != null ? build(items) : null;
  }
  
  public ClusterDomainClaim buildItem(int index) {
    return this.items.get(index).build();
  }
  
  public ClusterDomainClaim buildFirstItem() {
    return this.items.get(0).build();
  }
  
  public ClusterDomainClaim buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  
  public ClusterDomainClaim buildMatchingItem(Predicate<ClusterDomainClaimBuilder> predicate) {
    for (ClusterDomainClaimBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingItem(Predicate<ClusterDomainClaimBuilder> predicate) {
    for (ClusterDomainClaimBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withItems(List<ClusterDomainClaim> items) {
    if (this.items != null) { _visitables.get("items").clear();}
    if (items != null) {this.items = new ArrayList(); for (ClusterDomainClaim item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  
  public A withItems(io.fabric8.knative.internal.networking.v1alpha1.ClusterDomainClaim... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (ClusterDomainClaim item :items){ this.addToItems(item);}} return (A) this;
  }
  
  public boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  
  public ItemsNested<A> addNewItem() {
    return new ItemsNested(-1, null);
  }
  
  public ItemsNested<A> addNewItemLike(ClusterDomainClaim item) {
    return new ItemsNested(-1, item);
  }
  
  public ItemsNested<A> setNewItemLike(int index,ClusterDomainClaim item) {
    return new ItemsNested(index, item);
  }
  
  public ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  
  public ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public ItemsNested<A> editMatchingItem(Predicate<ClusterDomainClaimBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public ListMeta getMetadata() {
    return this.metadata;
  }
  
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterDomainClaimListFluent that = (ClusterDomainClaimListFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;
  
    if (!java.util.Objects.equals(items, that.items)) return false;
  
    if (!java.util.Objects.equals(kind, that.kind)) return false;
  
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  public class ItemsNested<N> extends ClusterDomainClaimFluent<ItemsNested<N>> implements Nested<N>{
    ItemsNested(int index,ClusterDomainClaim item) {
      this.index = index;
      this.builder = new ClusterDomainClaimBuilder(this, item);
    }
    ClusterDomainClaimBuilder builder;
    int index;
    
    public N and() {
      return (N) ClusterDomainClaimListFluent.this.setToItems(index,builder.build());
    }
    
    public N endItem() {
      return and();
    }
    
  
  }

}
